@@ -57,16 +57,71 @@ scgroup_err:
 
 static void usage(int status, const char *program_name)
 {
-	if (status != 0)
+	if (status != 0) {
 		fprintf(stderr, "Wrong input parameters,"
 			" try %s --help' for more information.\n",
 			program_name);
-	else {
-		printf("Usage: %s [-r <name=value>]  <cgroup_path> ...\n"
-			"   or: %s --copy-from <source_cgrup_path> "
-			    "<cgroup_path> ...\n",
-			program_name, program_name);
+		return;
 	}
+	printf("Usage: %s [-r <name=value>] <cgroup_path> ...\n"
+		"   or: %s --copy-from <source_cgroup_path> "\
+		"<cgroup_path> ...\n", program_name, program_name);
+	printf("Set the parameters of given cgroup(s)\n");
+	printf("  -r, --variable <name>			Define parameter "\
+		"to set\n");
+	printf("  --copy-from <source_cgroup_path>	Control group whose "\
+		"parameters will be copied\n");
+}
+
+STATIC int parse_r_flag(const char * const program_name,
+			const char * const name_value_str,
+			struct control_value * const name_value)
+{
+	int ret = 0;
+	char *copy, *buf;
+
+	copy = strdup(name_value_str);
+	if (copy == NULL) {
+		fprintf(stderr, "%s: not enough memory\n", program_name);
+		ret = -1;
+		goto err;
+	}
+
+	/* parse optarg value */
+	buf = strtok(copy, "=");
+	if (buf == NULL) {
+		fprintf(stderr, "%s: "
+			"wrong parameter of option -r: %s\n",
+			program_name, optarg);
+		ret = -1;
+		goto err;
+	}
+
+	strncpy(name_value->name, buf, FILENAME_MAX);
+	name_value->name[FILENAME_MAX-1] = '\0';
+
+	buf = strchr(name_value_str, '=');
+	/* we don't need to check the return value of strchr because we
+	 * know there's already an '=' character in the string.
+	 */
+	buf++;
+
+	if (strlen(buf) == 0) {
+		fprintf(stderr, "%s: "
+			"wrong parameter of option -r: %s\n",
+			program_name, optarg);
+		ret = -1;
+		goto err;
+	}
+
+	strncpy(name_value->value, buf, CG_CONTROL_VALUE_MAX);
+	name_value->value[CG_CONTROL_VALUE_MAX-1] = '\0';
+
+err:
+	if (copy)
+		free(copy);
+
+	return ret;
 }
 
 int main(int argc, char *argv[])
@@ -74,7 +129,6 @@ int main(int argc, char *argv[])
 	int ret = 0;
 	int c;
 
-	char *buf;
 	struct control_value *name_value = NULL;
 	int nv_number = 0;
 	int nv_max = 0;
@@ -124,31 +178,10 @@ int main(int argc, char *argv[])
 				}
 			}
 
-			/* parse optarg value */
-			/* there is necessary to input the tuple n=v */
-			buf = strtok(optarg, "=");
-			if (buf == NULL) {
-				fprintf(stderr, "%s: "
-					"wrong parameter of option -r: %s\n",
-					argv[0], optarg);
-				ret = -1;
+			ret = parse_r_flag(argv[0], optarg,
+					   &name_value[nv_number]);
+			if (ret)
 				goto err;
-			}
-
-			strncpy(name_value[nv_number].name, buf, FILENAME_MAX);
-			name_value[nv_number].name[FILENAME_MAX-1] = '\0';
-
-			buf = strtok(NULL, "=");
-			if (buf == NULL) {
-				fprintf(stderr, "%s: "
-					"wrong parameter of option -r: %s\n",
-					argv[0], optarg);
-				ret = -1;
-				goto err;
-			}
-
-			strncpy(name_value[nv_number].value, buf, CG_VALUE_MAX);
-			name_value[nv_number].value[CG_VALUE_MAX-1] = '\0';
 
 			nv_number++;
 			break;
@@ -227,9 +260,8 @@ int main(int argc, char *argv[])
 		/* modify cgroup based on values of the new one */
 		ret = cgroup_modify_cgroup(cgroup);
 		if (ret) {
-			fprintf(stderr, "%s: "
-				"the group can't be modified\n",
-				argv[0]);
+			fprintf(stderr, "%s: cgroup modify error: %s \n",
+				argv[0], cgroup_strerror(ret));
 			goto cgroup_free_err;
 		}
 
